#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifndef max
#define max(a, b)		((a) > (b) ? (a) : (b))
#endif

#define LN_REGS			4
#define LN_RSZ			4096
unsigned short lnreg[LN_REGS][LN_RSZ];
int lnsz[LN_REGS];
char lnbuf[LN_RSZ * 2];
void ln_set(int d, unsigned short v) {
	memset(lnreg[d], 0, sizeof(lnreg[d]));
	lnreg[d][0] = v;
	lnsz[d] = 1;
}
void ln_xcopy(int d, int s, int o) {
	memset(lnreg[d], 0, sizeof(lnreg[d][0]) * o);
	memcpy(lnreg[d] + o, lnreg[s], sizeof(lnreg[d][0]) * (LN_RSZ - o));
	lnsz[d] = lnsz[s] + o;
}
void ln_trim(int d) {
	while(lnsz[d] > 1 && !lnreg[d][lnsz[d] - 1])
		lnsz[d]--;
}
void ln_scan(int d, FILE *fp) {
	int x, sz;
	int tv;

	memset(lnreg[d], 0, sizeof(lnreg[d]));
	// load
	fscanf(fp, "%d", &sz);
	for(x = 0; x < sz; x++) {
		fscanf(fp, "%d", &tv);
		lnbuf[sz - x - 1] = tv;
	}

	lnsz[d] = (sz + 3) / 4;
	for(x = 0; x < lnsz[d]; x++)
		lnreg[d][x] = lnbuf[x * 4] + lnbuf[x * 4 + 1] * 10 + lnbuf[x * 4 + 2] * 100 + lnbuf[x * 4 + 3] * 1000;
}
void ln_print(FILE *fp, int d) {
	int x;

	fprintf(fp, "%d", lnreg[d][lnsz[d] - 1]);
	for(x = lnsz[d] - 2; x >= 0; x--)
		fprintf(fp, "%04d", lnreg[d][x]);
	fprintf(fp, "\n");
}

void ln_dmul(int d, unsigned short f) {
	unsigned long cf;
	int x;

	cf = 0;
	for(x = 0; x < lnsz[d]; x++) {
		cf += (unsigned long)f * lnreg[d][x];
		lnreg[d][x] = cf % 10000; cf /= 10000;
	}
	if(cf) lnreg[d][x++] = cf;
	lnsz[d] = x;
}
void ln_ddiv(int d, unsigned short f) {
	unsigned long cf;
	int x;

	cf = 0;
	for(x = lnsz[d] - 1; x >= 0; x--) {
		cf += lnreg[d][x];
		lnreg[d][x] = cf / f; cf %= f;
		cf *= 10000;
	}
	ln_trim(d);
}
void ln_add(int d, int s) {
	int m, x;
	int cf;

	cf = 0;
	m = max(lnsz[d], lnsz[s]);
	for(x = 0; x < m; x++) {
		if(lnreg[d][x] + lnreg[s][x] + cf < 10000) {
			lnreg[d][x] += lnreg[s][x] + cf;
			cf = 0;
		}
		else {
			lnreg[d][x] += lnreg[s][x] + cf - 10000;
			cf = 1;
		}
	}
	if(cf) lnreg[d][x++] = cf;
	lnsz[d] = x;
}
void ln_mul(int d, int f1, int f2) {
	int x;

	ln_set(d, 0);
	for(x = 0; x < lnsz[f2]; x++) {
		ln_xcopy(0, f1, x);
		ln_dmul(0, lnreg[f2][x]);
		ln_add(d, 0);
	}
}

int main() {
	FILE *fp;

	// load
	fp = fopen("sala.in", "rt");
	ln_scan(1, fp);
	ln_trim(1);
	fclose(fp);

	// score
	fp = fopen("sala.out", "wt");

		// R: [(n * (n + 1) + 1) / 3]
		ln_xcopy(2, 1, 0);
		ln_set(3, 1);
		ln_add(2, 3); // n + 1
		ln_mul(3, 1, 2); // n(n + 1)

		ln_set(1, 1);
		ln_add(3, 1); // n(n + 1) + 1

		ln_ddiv(3, 3); // (n(n + 1) + 1) / 3

		ln_trim(3); // just to be on the safe side
		ln_print(fp, 3);
	fclose(fp);

	return 0;
}