#include <stdio.h>
#include <math.h>

#undef PI
#define PI 3.141592654
#define EPS 1e-7

#define rad2deg(x) ((x) * 180.0 / PI)

int N, X, Y;
int L[10010];
double D;

int P, R1, R2;
double A1, A2;

int getbreakpoint()
{
    int i;
    D = sqrt((double) X * (double) X + (double) Y * (double) Y);
    for (i = 1; i <= N; i++) R2 += L[i];
    if (R2 < D-EPS) return -1;
    for (i = 1; i <= N; i++)
    {
        R1 += L[i], R2 -= L[i];
        if (fabs(R2 - R1) < D + EPS)
           return i;
    }
    return -1;
}

/* angle opposite of a in a triangle */
double angle(double a, double b, double c)
{
    double cs;
    cs = (b*b + c*c - a*a) / (2 * b * c);
    if (cs < -1.0) cs = -1.0;
    if (cs > 1.0) cs = 1.0;
    return rad2deg(acos(cs));
}

void solve()
{
    P = getbreakpoint();
    if (P < 0) return;
    A1 = angle(R2, R1, D);
    A1 += rad2deg(atan2(Y, X));
    A2 = angle(D, R1, R2) + 180.0;
    
    if (A1 > 360.0-EPS) A1 -= 360.0;
    if (A2 >= 360.0-EPS) A2 -= 360.0;
}

void print()
{
    FILE *fo = fopen("robot.out", "wt");
    int i;
    if (P < 0)
        fprintf(fo, "0\n");
    else
    {
        fprintf(fo, "%.6lf\n", A1);
        for (i = 1; i < P; i++)
            fprintf(fo, "0\n");
        fprintf(fo, "%.6lf\n", A2);
        for (i = P+1; i < N; i++)
            fprintf(fo, "0\n");
    }
    fclose(fo);
}
        

void read_data()
{
    FILE *fi = fopen("robot.in", "rt");
    int i;
    fscanf(fi, "%d", &N);
    for (i = 1; i <= N; i++)
        fscanf(fi, "%d", L+i);
    fscanf(fi, "%d %d", &X, &Y);
    fclose(fi);
}

int main()
{
    read_data();
    solve();
    print();
    return 0;
}
