#include <stdio.h>
#include <math.h>
#include <alloc.h>


const double PI   = 3.1415926535897932384626433832795;
const double PI2  = PI*2;
const double RtoD = 180.0 / PI;
const double DtoR = PI / 180.f;

inline double makeAng(double me)
{
    me = fmod(me, PI2);
    if (me < 0.0) me += PI2;

    return me;
}


struct m_point
{
   double x, y, ang, F;
};

int main(void)
{
   long   len[10000], xf, yf, N, i, j;
   double mX, mY, lmX, lmY;

   m_point far *ankle = (m_point far*)farmalloc(sizeof(m_point)* 10002);
   float   ang [10000];
   float   tens[10000];


   double dist, lenT = 0.0, curDist;
   double curAng;
   int OK;

   FILE *f = fopen("robot.in", "r");
   fscanf(f, "%ld\n", &N);
   for (i=0; i<N; i++)
   {
       fscanf(f, "%ld\n", len+i);
       lenT += len[i];
   }
   fscanf(f, "%ld %ld", &xf, &yf);
   fclose(f);


   dist   = sqrt(((long double)xf) * xf + ((long double)yf)*yf);

   if (dist > lenT || len[N-1] - len[0] > dist)
   {
       f = fopen("robot.out", "w");
       fprintf(f, "0\n");
       fclose(f);
       return 0;
   }

   ang[0]  = asin(xf/dist);
   if (yf < 0.0f) ang[0] = PI2-ang[0];
   dist   /= lenT;
   curDist = 0;

   for (i=1; i<N; i++)
   {
      ang[i] = 0.0f;
      tens[i] = len[i] * dist;

      curDist += len[i] / lenT;

      ankle[i].x = xf * curDist;
      ankle[i].y = yf * curDist;
   }

   ankle[0].x = ankle[0].y = 0.0;
   ankle[N].x = xf;
   ankle[N].y = yf;


   //-------------------------------------
   OK = 1;
   int iteratii = 0;
   while (OK)
   {
       OK = 0;
       for (i=0; i<=N; i++) ankle[i].F = 0.0f;

       for (i=0; i<N; i++)
       {
	  if (fabs(tens[i] - 1.0) > 1e-5)
	  {
	      OK = 1;
	      if (i!=0 && i+1 != N)
	      {

		 ankle[i  ].F -= tens[i] * 0.5f;
		 ankle[i+1].F -= tens[i] * 0.5f;
	      } else {
		 if (i   == 0) ankle[1  ].F += tens[i];
		 if (i+1 == N) ankle[N-1].F -= tens[i];
	      }
	  }
       }

       if (OK)
       {
	   curAng = ang[0];
	   for (i=1; i<N; i++)
	   {
	       ankle[i].ang = makeAng(curAng + (PI+ang[i])*0.5f);
	       curAng += ang[i];

	       ankle[i].x += sin(ankle[i].ang) * ankle[i].F / len[i];
	       ankle[i].y += cos(ankle[i].ang) * ankle[i].F / len[i];
	   }

	   dist = 0;

	   lmX = 1.0;
	   lmY = 0.0;

	   for (i=0; i<N; i++)
	   {
	       mX = ankle[i+1].x - ankle[i].x;
	       mY = ankle[i+1].y - ankle[i].y;

	       ankle[i].F = sqrt(mX*mX + mY*mY);
	       dist += ankle[i].F;

	       // calc ang
	       mX /= ankle[i].F;
	       mY /= ankle[i].F;

	       curAng = asin(mX*lmY - lmX*mY);
	       if (mX*lmX + mY*lmY > 0) curAng = PI2 - curAng;
	       ang[i] = curAng;

	       lmX = mX;
	       lmY = mY;
	   }

	   dist /= lenT;
	   curAng = ang[0];
	   for (i=0; i<N; i++)
	   {
	       tens[i] = len[i] * dist;

	       if (i)
	       {
		   ankle[i].x = ankle[i-1].x + sin(curAng)*len[i-1];
		   ankle[i].y = ankle[i-1].y + cos(curAng)*len[i-1];
		   curAng += ang[i];
	       }
	   }
       }

       iteratii++;
   }
   //-------------------------------------


   f = fopen("robot.out", "w");

   for (i=0; i<N; i++)
      fprintf(f, "%.10f\n", makeAng(ang[i])*RtoD);

   fclose(f);


   return 0;
}