/* Complexity: O(N^3) */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef __BORLANDC__
#define LN_REGS 410
#define LN_SZ 	64
#else
#define LN_REGS 512
#define LN_SZ		1024
#define max(a, b)             ((a) > (b) ? (a) : (b))
#endif
unsigned short lnreg[LN_REGS][LN_SZ];
int lnsz[LN_REGS];
void ln_set(int d, unsigned short v) {
	memset(lnreg[d], 0, sizeof(lnreg[d]));
	lnreg[d][0] = v; lnsz[d] = 1;
}
void ln_copy(int d, int s) {
	memcpy(lnreg[d], lnreg[s], sizeof(lnreg[s]));
	lnsz[d] = lnsz[s];
}
void ln_xcopy(int d, int s, int o) {
	memset(lnreg[d], 0, sizeof(lnreg[s][0]) * o);
	memcpy(lnreg[d] + o, lnreg[s], sizeof(lnreg[s]) - sizeof(lnreg[s][0]) * o);
	lnsz[d] = lnsz[s] + o;
}

void ln_print(FILE *fp, int s) {
	int x;

	fprintf(fp, "%d", lnreg[s][lnsz[s] - 1]);
	for(x = lnsz[s] - 2; x >= 0; x--)
		fprintf(fp, "%04d", lnreg[s][x]);
	fprintf(fp, "\n");
}
void ln_add(int d, int s) {
	int x, m;
	int cf;

	m = max(lnsz[d], lnsz[s]);
	cf = 0;
	for(x = 0; x < m; x++) {
		if(lnreg[d][x] + lnreg[s][x] + cf < 10000) {
			lnreg[d][x] += lnreg[s][x] + cf;
			cf = 0;
		}
		else {
			lnreg[d][x] += lnreg[s][x] + cf - 10000;
			cf = 1;
		}
	}
	if(cf) lnreg[d][x++] = cf;
	lnsz[d] = x;
}
void ln_dmul(int d, unsigned short f) {
	unsigned long cf;
	int x;

	cf = 0;
	for(x = 0; x < lnsz[d]; x++) {
		cf += (unsigned long)f * lnreg[d][x];
		lnreg[d][x] = cf % 10000; cf /= 10000;
	}
	if(cf) lnreg[d][x++] = cf;
	lnsz[d] = x;
}
void ln_mul(int d, int f1, int f2) {
	int x;

	ln_set(d, 0);
	for(x = 0; x < lnsz[f2]; x++) {
		ln_xcopy(0, f1, x);
		ln_dmul(0, lnreg[f2][x]);
		ln_add(d, 0);
	}
}

void do_stl(int n, int k) {
	int i, x;

	// S(0, e) = 1
	if(k == 0)
		ln_set(302, 1);

	// S(1, 1) = 1
	ln_set(101, 1);
	ln_copy(302 + 1, 100 + k);

	for(i = 2; i <= n; i++) {
		ln_set(1, 1);
		for(x = 2; x <= i; x++) {
			// S(n, k) = S(n - 1, k - 1) + k * S(n - 1, k)
			ln_copy(x, 100 + x);
			ln_dmul(x, x);
			ln_add(x, 100 + x - 1);
		}

		for(x = 1; x <= i; x++)
			ln_copy(100 + x, x);
		ln_copy(302 + i, 100 + k);
	}
}

void do_comb(int n) {
	int i, x;

	// C(0,0) = 1
	ln_set(201 + 0, 1);
	for(i = 1; i <= n; i++) {
		// C(0, n) = 0
		ln_set(0, 1);
		for(x = 1; x <= i; x++) {
			// C(k, n) = C(k - 1, n - 1) + C(k, n - 1)
			ln_copy(x, 201 + x - 1);
			ln_add(x, 201 + x);
		}

		for(x = 0; x <= i; x++)
			ln_copy(201 + x, x);
	}
}

void do_reset() {
	memset(&lnreg[0], 0, sizeof(lnreg[0]) * 101);
	memset(&lnsz[0], 0, sizeof(lnsz[0]) * 101);
}

int main() {
	FILE *fp;
	int n, k, p;
	int e;

	// load
	fp = fopen("ex.in", "rt");
	fscanf(fp, "%d%d%d", &n, &k, &p);
	fclose(fp);

	// precompute
	do_comb(n - k);
	do_reset();
	do_stl(n - k, p - k);

		// the actual thing -- R #0 is used for mul computations
		ln_set(1, 0); ln_set(2, 1);
		for(e = 0; e <= n - k; e++) {
			if(n - k - e >= p - k) {
				// S += C(e, n) * k ^ e * S(n - k - e, p - k)
				ln_mul(3, 201 + e, 2);
				ln_mul(4, 3, 302 + n - k - e);

				ln_add(1, 4);
				ln_dmul(2, k);
			}
		}

	// score
	fp = fopen("ex.out", "wt");
	ln_print(fp, 1);
	fclose(fp);

	return 0;
}

