/* Complexity: O(N) */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

double my_atan2(double dy, double dx) {
	double r;

	r = atan2(dy, dx);
	if(r < 0.0) r = M_PI - r;
	return r;
}
double my_angle(double a) {
	a = 180.0 * a / M_PI;
	while(a < 0.0) a += 360.0;
	while(a >= 360.0) a -= 360.0;
	return a;
}

double cx1, cy1;
double ralpha, rbeta;

// new solution - binary search
// solve circle equation for (0, r1) ((cx1, cy1), r2)
// solution in ralpha
int solve_ec(double r1, double r2) {
	double dx, dy;
	double a, b, x;
	double d2;
	int w;

	d2 = sqrt(cx1 * cx1 + cy1 * cy1);
	if(r1 + r2 - d2 <= -1e-5)
		return 0;
	if(d2 - fabs(r1 - r2) <= -1e-5)
		return 0;

	a = my_atan2(cy1, cx1);
	b = a + M_PI;
	for(w = 0; w < 128; w++) {
		x = (a + b) * .5;
		dx = cx1 - cos(x) * r1; dy = cy1 - sin(x) * r1;
		d2 = sqrt(dx * dx + dy * dy);
		if(d2 > r2) b = x;
		else a = x;
	}

	ralpha = x;
	rbeta = my_atan2(dy, dx);
	return 1;
}

int asz[16384];
int main() {
	double r1, r2, r3;
	double ra, rb, rc;
	FILE *fp;
	long s, s0;
	int n, x, xm;
	int ssol;

	// load
	fp = fopen("robot.in", "rt");
	fscanf(fp, "%d", &n);
	for(x = 0; x < n; x++)
		fscanf(fp, "%d", &asz[x]);
	fscanf(fp, "%lf%lf", &cx1, &cy1);
	fclose(fp);

	// process 1 - find median segment
	s = 0;
	for(x = 0; x < n; x++) s += asz[x];
	s0 = 0;
	for(xm = 0; xm < n; xm++) {
		if(s0 < s && s0 + asz[xm] >= s - asz[xm]) break;
		s -= asz[xm];
		s0 += asz[xm];
	}
	ra = s0; rb = asz[xm]; rc = s - asz[xm];

	// process 2 - find angles
	ssol = 1;
	if(solve_ec(ra + rb, rc)) {
		r1 = r2 = ralpha; r3 = rbeta;
	}
	else if(solve_ec(ra, rb + rc)) {
		r1 = ralpha; r2 = r3 = rbeta;
	}
	else if(solve_ec(ra, fabs(rb - rc))) {
		r1 = ralpha;
		if(rb > rc) { r2 = rbeta; r3 = -rbeta; }
		else { r2 = -rbeta; r3 = rbeta; }
	}
	else {
		ssol = 0;
	}

	// score
	fp = fopen("robot.out", "wt");
	if(ssol) {
		for(x = 0; x < n; x++) {
			if(!x) fprintf(fp, "%.12lf\n", my_angle(r1));
			else if(x == xm) fprintf(fp, "%.14lf\n", my_angle(r2 - r1));
			else if(x == xm + 1) fprintf(fp, "%.14lf\n", my_angle(r3 - r2));
			else fprintf(fp, "0\n");
		}
	}
	else fprintf(fp, "0\n");
	fclose(fp);

	return 0;
}

