#include <stdio.h>
#include <string.h>

#define max(a,b) ((a) > (b) ? (a) : (b))

#define RADIX 1000

typedef int bigint[32];

int N, K, P;
bigint C[128][128];
bigint S[128][128];
bigint A[128][128];
bigint B[128][128];

void init(bigint X, int x)
{
	memset(X, 0, sizeof(bigint));
	X[0] = 1;
	X[1] = x;
}

void add(bigint X, bigint Y)
{
	int i, t;

	t = 0;
	X[0] = max(X[0], Y[0]);
	for (i = 1; i <= X[0]; i++)
	{
		X[i] += Y[i] + t;
		t = X[i] / RADIX;
		X[i] %= RADIX;
	}
	if (t)
		X[++X[0]] = t;
}

void mult(bigint A, bigint X, bigint Y)
{
	int i, j, t;

	memset(A, 0, sizeof(A));
	A[0] = X[0] + Y[0] - 1;
	for (i = 1; i <= X[0]; i++)
		for (j = 1; j <= Y[0]; j++)
			A[i + j - 1] += X[i] * Y[j];
	t = 0;
	for (i = 1; i <= A[0]; i++)
	{
		A[i] += t;
		t = A[i] / RADIX;
		A[i] %= RADIX;
	}
	while (t)
	{
		A[++A[0]] = t % RADIX;
		t /= RADIX;
	}
}

void mults(bigint x, int y)
{
	int t, i;

	t = 0;
	for (i = 1; i <= x[0]; i++)
	{
		x[i] = x[i] * y + t;
		t = x[i] / RADIX;
		x[i] %= RADIX;
    }
	while (t)
	{
		x[++x[0]] = t % RADIX;
		t /= RADIX;
	}
}

void print(FILE *fp, bigint X)
{
	int i;

	fprintf(fp, "%d", X[X[0]]);
	for (i = X[0] - 1; i; i--)
		fprintf(fp, "%03d", X[i]);
}

int main(void)
{
	FILE *fp;
	int i, j, k, x;
	bigint temp, tm;
	
	k = 0;
	fp = fopen("ex.in", "r");
	fscanf(fp, "%d %d %d", &N, &K, &P);
	fclose(fp);
	
	memset(C, 0, sizeof(C));
	init(C[0][0], 1);
	for (i = 1; i <= N; i++)
		init(C[i][0], 1);
	for (i = 1; i <= N; i++)
		for (j = 1; j <= i; j++)
		{
			memcpy(C[i][j], C[i - 1][j - 1], sizeof(bigint));
			add(C[i][j], C[i - 1][j]);
		}

	memset(B, 0, sizeof(B));
	init(B[1][1], 1);
	for (i = 2; i <= N; i++)
		for (j = 1; j <= i; j++)
        {
			add(B[i][j], B[i - 1][j - 1]);
			memcpy(temp, B[i - 1][j], sizeof(bigint));
			mults(temp, j);
			add(B[i][j], temp);
		}

    memset(A, 0, sizeof(A));
	for (i = 1; i <= N; i++)
		for (j = 1; j <= N; j++)
		{
			memcpy(A[i][j], B[i][j], sizeof(bigint));
			for (k = 1; k < j; k++)
            {
				mult(temp, B[i][j - k], C[j][k]);
				add(A[i][j], temp);
			}
        }

    init(temp, 0);
	for (x = P - K; x <= N - K; x++)
    {
		if (N - x - K <= 0) continue;
		mult(tm, B[x][P - K], A[N - x - K][K]);
		add(temp, tm);
	}

	fp = fopen("ex.out", "w");
	print(fp, temp);
	fprintf(fp, "\n");
	fclose(fp);

	return 0;
}



