#include <fstream.h>
#include <iostream.h>
#include <math.h>

ifstream in("robot.in");
ofstream out("robot.out");

typedef double real;

struct vector
{
	real x,y;
	vector(){};	
	vector(real _x,real _y){x=_x;y=_y;};
};

inline vector operator+(const vector &a,const vector &b)
{return vector(a.x+b.x,a.y+b.y);}
inline vector operator-(const vector &a,const vector &b)
{return vector(a.x-b.x,a.y-b.y);}
inline vector operator*(const vector &a,real x){return vector(a.x*x,a.y*x);}
inline vector operator/(const vector &a,real x){return a*1/x;}
inline real sqlength(const vector& v){return v.x*v.x+v.y*v.y;}
inline real length(const vector& v){return sqrt(v.x*v.x+v.y*v.y);}
inline vector norm(const vector& v){return v/length(v);}
inline real dotprod(const vector &a,const vector &b){return a.x*b.x+a.y*b.y;}
inline real crossprod(const vector &a,const vector &b){return a.x*b.y-a.y*b.x;}
istream& operator>>(istream &is,vector &v)
{is>>v.x>>v.y;return is;}
ostream& operator<<(ostream &os,const vector &v)
{os<<v.x<<' '<<v.y;return os;}
template<class T>inline T abs(T x){return x>=0?x:-x;}
template<class T>inline T max(T x,T y){return x>y?x:y;}
template<class T>inline T min(T x,T y){return x>y?y:x;}

#define MAXN 11000
int n;
real len[MAXN];
vector dest;
real ang[MAXN];

void read()
{
	in>>n;
	for (int i=0;i<n;i++) in>>len[i];
	in>>dest;
	for (int i=0;i<n;i++) in>>ang[i];
}

void check()
{
	vector loc(0,0);
	real angle=0;
	//out<<"Start from "<<loc<<" angle="<<angle<<'\n';
	for (int i=0;i<n;i++)
	{
		angle+=ang[i];
		loc.x+=cos(angle*M_PI/180)*len[i];
		loc.y+=sin(angle*M_PI/180)*len[i];
		out<<"I'm at "<<loc<<" angle="<<angle<<'\n';
	}
	if ((max(abs(loc.x-dest.x),abs(loc.y-dest.y)))>=0.001)
		out<<":(";
}

real mindist[MAXN],maxdist[MAXN];

void calc()
{
	mindist[0]=maxdist[0]=len[0];
	for (int i=1;i<n;i++)
	{
		mindist[i]=min(abs(maxdist[i-1]-len[i]),abs(mindist[i-1]-len[i]));
		maxdist[i]=max(abs(maxdist[i-1]+len[i]),abs(mindist[i+1]-len[i]));
	}
}

bool calcang()
{
	real angl=atan2(dest.y,dest.x)*180/M_PI;
	real dist=length(dest),nd=0,a,b;
	if (dist<mindist[n-1]||dist>maxdist[n-1])
		return false;
	out<<angl<<"\n";
	ang[n]=0;
	for (int i=n;i>0;i--)
	{
		out<<i<<" "<<dist<<" "<<mindist[i-1]<<','<<maxdist[i-1]<<' '<<len[i]<<' ';
		if (dist<maxdist[i-1])
			nd=min(maxdist[i-1]-dist,len[i]);			
		if (dist>mindist[i-1])
			nd=max(mindist[i-1]-dist,-len[i]);
		out<<"I decided to travel "<<nd<<' ';
		nd+=dist;
		out<<nd<<' '<<dist<<' '<<len[i]<<' ';
		a=(dist*dist+len[i]*len[i]-nd*nd)/(2*dist*len[i]);
		b=(nd*nd+len[i]*len[i]-dist*dist)/(2*nd*len[i]);
		out<<a<<' '<<b<<'\n';
		a=acos(a)*180/M_PI;		
		b=acos(b)*180/M_PI;		
		out<<a<<' '<<b<<'\n';
		ang[i]=b;
		ang[i+1]+=a;
		angl-=ang[i+1];
		out<<"angl="<<angl<<'\n';
		dist=nd;
	}
	while (angl<0) angl+=180;
	ang[0]=angl;
	return true;
}

int main()
{
	read();
	calc();
	if (calcang())
	{
		check();
		for (int i=0;i<n;i++)
			out<<ang[i]<<'\n';
	}	
	else 
		out<<"0\n";
	return 0;
}

