#include <stdio.h>
#include <math.h>
#include <stdlib.h>

#define HULLSIZE 10010
#define SIZE 5010

struct point
{
    double x, y;
} P[HULLSIZE];
typedef struct point point;
int N;
#define EPS 1e-4

double chullarea();

point P1[SIZE], P2[SIZE];
double A[SIZE], B[SIZE], C[SIZE];
int M;

double Res;

void getparams()
{
    int i;
    for (i = 0; i < M; i++)
    {
        A[i] = P1[i].y - P2[i].y;
        B[i] = P2[i].x - P1[i].x;
        C[i] = P2[i].y * P1[i].x - P1[i].y * P2[i].x;
    }
}

#define INF 1e100
void getpoints(int n)
{
    int i;
    double x0, y0, dx, dy, t;
    double tmin = INF, tmax = -INF;
    x0 = P1[n].x, y0 = P1[n].y;
    dx = P2[n].x-x0, dy = P2[n].y-y0;
    for (i = 0; i < M; i++)
    if (i != n)
    {
        t = - (A[i] * x0 + B[i] * y0 + C[i]) / (A[i] * dx + B[i] * dy);
        if (tmin > t) tmin = t;
        if (tmax < t) tmax = t;
    }
    P[N].x = x0 + tmin * dx, P[N].y = y0 + tmin * dy, N++;
    P[N].x = x0 + tmax * dx, P[N].y = y0 + tmax * dy, N++;
}

void solve()
{
    int i;
    getparams();
    for (i = 0; i < M; i++)
        getpoints(i);
    Res = chullarea();
}

void print()
{
    FILE *fo = fopen("inter.out", "wt");
    fprintf(fo, "%.2lf\n", Res);
    fclose(fo);
}

void read_data()
{
    FILE *fi = fopen("inter.in", "rt");
    int i;
    fscanf(fi, "%d", &M);
    for (i = 0; i < M; i++)
        fscanf(fi, "%lf %lf %f %lf", &P1[i].x, &P1[i].y, &P2[i].x, &P2[i].y);
    fclose(fi);
}

int main()
{
    read_data();
    solve();
    print();
    return 0;
}


/* Convex hull area */

#define sqr(x) ((x)*(x))
#define dist(i, j) (sqr((i).x - (j).x) + sqr((i).y - (j).y))

#define det(i, j, k) (((k).x-(i).x) * ((j).y-(i).y) - ((j).x-(i).x) * ((k).y-(i).y))

double _t;
int cmp(const void *a, const void *b)
{
    _t = det(P[0], *((point *) a), *((point *) b));
    if (fabs(_t) < EPS) return 0;
    return dist(P[0], *((point *) a)) < dist(P[0], *((point *) b)) ? -1 : 1;
}

int S[HULLSIZE], ss;

void add(int p)
{
    while (ss > 1 && det(P[p], P[S[ss-1]], P[S[ss-2]]) < 0) ss--;
    S[ss++] = p;
}

double chullarea()
{
    int i;
    double area = 0;
    point t;
    for (i = 1; i < N; i++)
        if (P[i].x < P[0].x || (fabs(P[i].x == P[0].x) < EPS && P[i].y < P[0].y))
           t = P[0], P[0] = P[i], P[i] = t;
    qsort(P+1, N-1, sizeof(point), cmp);
    for (i = ss = 0; i <= N; i++) add(i%N);
    for (i = 0; i < ss-1; i++)
        area += P[S[i]].x * P[S[i+1]].y - P[S[i]].y * P[S[i+1]].x;
    return fabs(area*0.5);
}

