#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define min(a,b) ((a) < (b) ? (a) : (b))
#define max(a,b) ((a) > (b) ? (a) : (b))

typedef struct t_line
{
	double y1, x1, y2, x2;
} line;

typedef struct t_point
{
	double y, x;
} point;

#define EPS 1e-4
#define greater(a,b) ((a) + EPS > (b))
#ifdef abs
#undef
#endif
#define abs(x) ((x) > 0 ? (x) : -(x))
#define eq(a,b) (abs(a - b) < EPS)

double area;
line l[8192];
point p[8192][2];
point q[16384], n[16384];
int N, st[16384], NN;
int np[8192];

int inbetween(point *p, point *p1, point *p2)
{
	double miny, minx, maxy, maxx;
	
	miny = min(p1->y, p2->y);
	maxy = max(p1->y, p2->y);
	minx = min(p1->x, p2->x);
	maxx = max(p1->x, p2->x);
	if (greater(p->y, miny) && greater(maxy, p->y) &&
		greater(p->x, minx) && greater(maxx, p->x))
		return 1;
	return 0;
}

void inters(line *l1, line *l2, point *p)
{
	double y1, y2, y3, y4;
	double x1, x2, x3, x4;
	double delta, deltax, deltay;
	
	y1 = l1->y1;
	y2 = l1->y2;
	y3 = l2->y1;
	y4 = l2->y2;
	x1 = l1->x1;
	x2 = l1->x2;
	x3 = l2->x1;
	x4 = l2->x2;
	delta = (y1 - y2) * (x4 - x3) - (y3 - y4) * (x2 - x1);
	deltax = (x2 * y1 - x1 * y2) * (x4 - x3) -
		(x4 * y3 - x3 * y4) * (x2 - x1);
	deltay = (y1 - y2) * (x4 * y3 - x3 * y4) -
		(y3 - y4) * (x2 * y1 - x1 * y2);
	p->x = deltax / delta;
	p->y = deltay / delta;
}

int compare(const void *a, const void *b)
{
	point *pa = (point *)a, *pb = (point *)b;
	
	if (pa->y * pb->x < pb->y * pa->x)
		return -1;
	return 1;
}

int compare_simple(const void *a, const void *b)
{
	point *pa = (point *)a, *pb = (point *)b;

	if (pa->y < pb->y)
		return -1;
    if (pa->y > pb->y)
		return 1;
    if (pa->x < pb->x)
		return -1;
    return 1;
}

int turns_right(point *p, point *a, point *b)
{
	double y1, y2, x1, x2;
	
	y1 = a->y - p->y;
	y2 = b->y - p->y;
	x1 = a->x - p->x;
	x2 = b->x - p->x;
	if (greater(y2 * x1, y1 * x2))
		return 0;
	return 1;
}

int main(void)
{
	FILE *fp;
	int i, j, ns, pos;
	point t;
	double miny, minx;
	
	fp = fopen("inter.in", "r");
	fscanf(fp, "%d", &N);
	for (i = 0; i < N; i++)
		fscanf(fp, "%lf %lf %lf %lf", &l[i].y1, &l[i].x1, &l[i].y2, &l[i].x2);
	fclose(fp);
	
	memset(np, 0, sizeof(np));
	for (i = 0; i < N - 1; i++)
		for (j = i + 1; j < N; j++)
		{
			inters(&l[i], &l[j], &t);
			if (np[i] < 2)
				p[i][np[i]++] = t;
			else
			{
				if (inbetween(&p[i][0], &t, &p[i][1]))
					p[i][0] = t;
				else if (inbetween(&p[i][1], &t, &p[i][0]))
					p[i][1] = t;
			}
		}
	for (i = 0; i < N; i++)
	{
		q[(i << 1)] = p[i][0];
		q[(i << 1) | 1] = p[i][1];
	}
	N <<= 1;

	qsort(q, N, sizeof(q[0]), compare_simple);
	n[0] = q[0];
	NN = 1;
	for (i = 1; i < N; i++)
		if (!eq(q[i].x, q[i - 1].x) || !eq(q[i].y, q[i - 1].y))
			n[NN++] = q[i];
	N = NN;
	memcpy(q, n, sizeof(q));
	
	miny = q[0].y;
	minx = q[0].x;
	pos = 0;
	for (i = 1; i < N; i++)
	{
		if (greater(miny, q[i].y))
		{
			miny = q[i].y;
			minx = q[i].x;
			pos = i;
		}
		else if (eq(q[i].y, miny) && greater(minx, q[i].x))
		{
			miny = q[i].y;
			minx = q[i].x;
			pos = i;
		}
	}
	for (i = 0; i < N; i++)
		q[i].y -= miny, q[i].x -= minx;

	t = q[pos];
	q[pos] = q[0];
	q[0] = t;

	qsort(q + 1, N - 1, sizeof(q[0]), compare);
	
	st[0] = 0;
	st[1] = 1;
	st[2] = 2;
	ns = 3;
	for (i = 3; i < N; i++)
	{
		st[ns++] = i;
		while (ns > 3 && turns_right(&q[st[ns - 3]], &q[st[ns - 2]], &q[ns - 1]))
		{
			st[ns - 2] = st[ns - 1];
			ns--;
		}
	}
	
	st[ns++] = st[0];
	
	area = 0;
	for (i = 0; i < ns; i++)
		area += q[st[i]].x * q[st[i + 1]].y - q[st[i]].y * q[st[i + 1]].x;
	area /= 2;
	if (area < 0) area = -area;

	fp = fopen("inter.out", "w");
	fprintf(fp, "%.2lf\n", area);
	fclose(fp);

	return 0;
}

